@@ -50,7 +50,7 @@ setMethod("export", c("ANY", "BEDFile"),
             if (class(track) == "try-error") {
               track <- try(as(object, "GenomicRangesList"), silent = TRUE)
               if (is(track, "try-error"))
-                stop("cannot export object of class '", cl, "': ", track)
+                stop("cannot export object of class '", cl, "'")
             }
             export(track, con, ...)
           })
@@ -300,7 +300,8 @@ setMethod("import", "BEDFile",
                                    presentClasses, "NULL")
               bed <- DataFrame(read.table(con, colClasses = bedClasses,
                                           as.is = TRUE, na.strings = ".",
-                                          comment.char = ""))
+                                          comment.char = "",
+                                          sep = "\t"))
             } else {
               if (is.null(colnames))
                 colnames <- character()
