@@ -42,11 +42,9 @@ test_wig <- function() {
   test_wig_con <- file(test_wig)
   test <- import(test_wig_con, format = "wig")
   checkIdentical(correct_ucsc, test)
-  close(test_wig_con)
   test_wig_con <- file(test_wig)
   test <- import(WIGFile(test_wig_con))
   checkIdentical(correct_ucsc, test)
-  close(test_wig_con)
   
   ## TEST: 'genome'
   hg19_seqinfo <- SeqinfoForBSGenome("hg19")
@@ -111,11 +109,13 @@ test_wig <- function() {
   default_line <- new("GraphTrackLine", name = "R Track", type = "bedGraph")
   correct_default <- new("UCSCData", correct_gr, trackLine = default_line)
   checkIdentical(test, correct_default)
-  correct_chr18 <- keepSeqlevels(correct_gr, "chr18")
+  correct_chr18 <- keepSeqlevels(correct_gr, "chr18", pruning.mode="coarse")
   export.ucsc(correct_chr18, test_wig_out)
   test <- import(test_wig_out)
   default_line <- new("GraphTrackLine", name = "R Track", type = "wig")
-  correct_default <- new("UCSCData", keepSeqlevels(correct_gr, "chr18"),
+  correct_default <- new("UCSCData",
+                         keepSeqlevels(correct_gr, "chr18",
+                                       pruning.mode="coarse"),
                          trackLine = default_line)
   checkIdentical(test, correct_default)
   
